Module action

Module action 

Trait for defining interactive, selectable CLI actions.

Traits

Action
An enumerable command that can be presented to the user as an interactive CLI selection and then executed against a shared Context.